@@ -5,21 +5,22 @@ SVG::Plot - a simple module to take one or more sets of x,y points and plot them
 =head1 SYNOPSIS
 
    use SVG::Plot;
-   my $points = [[0,1,'http://uri/'],[2,3,'/uri/foo.png']];
+   my $points = [ [0, 1, 'http://uri/'], [2, 3, '/uri/foo.png'] ];
    my $plot = SVG::Plot->new(
-                              points => $points,
-                              debug => 0,
-                              scale => 0.025,
-                              max_width => 800,
-                              max_height => 400,
-                              point_size => 3,
+                              points      => $points,
+                              debug       => 0,
+                              scale       => 0.025,
+                              max_width   => 800,
+                              max_height  => 400,
+                              point_size  => 3,
                               point_style => {
-                                  fill => 'blue',
-                                  stroke => 'yellow'
-                              },
-                              line => 'follow',
-                              margin => 6,
+                                               fill   => 'blue',
+                                               stroke => 'yellow',
+                                             },
+                              line        => 'follow',
+                              margin      => 6,
                             ); 
+
    # -- or --
    $plot->points($points);
    $plot->scale(4);
@@ -38,13 +39,13 @@ see B<new> for a list of parameters you can give to the plot. (overriding the st
 
 package SVG::Plot;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 use strict;
 use SVG;
 use Carp qw( croak );
 use Algorithm::Points::MinimumDistance;
 
-use Class::MethodMaker new_hash_init => 'new', get_set => [ qw( debug grid scale points pointsets image point_style point_size min_point_size max_point_size margin line line_style max_width max_height ) ];
+use Class::MethodMaker new_hash_init => 'new', get_set => [ qw( debug grid scale points pointsets image point_style point_size min_point_size max_point_size margin line line_style max_width max_height svg_options) ];
 
 =head1 METHODS
 
@@ -57,56 +58,63 @@ use Class::MethodMaker new_hash_init => 'new', get_set => [ qw( debug grid scale
   # Simple use - single set of points, all in same style.
   my $points = [ [0, 1, 'http://uri/'], [2, 3, '/uri/foo.png'] ];
   my $plot = SVG::Plot->new(
-                             points => \@points,
-		             point_size => 3,
-		             point_style => {
-		                 fill => 'blue',
-		                 stroke => 'yellow'},
-      		             line => 'follow',
-                             debug => 0,
-		             scale => 0.025,
-                             max_width => 800,
-                             max_height => 400,
-                             margin => 6,
+                             points      => \@points,
+                             point_size  => 3,
+                             point_style => {
+                                              fill   => 'blue',
+                                              stroke => 'yellow',
+                                            },
+                             line        => 'follow',
+                             debug       => 0,
+                             scale       => 0.025,
+                             max_width   => 800,
+                             max_height  => 400,
+                             margin      => 6,
                            );
 
   # Prepare to plot two sets of points, in distinct styles.
   my $pubs      = [
-      [ 522770, 179023, "http://example.com/?Andover_Arms ],
-      [ 522909, 178232, "http://example.com/?Blue Anchor  ] ];
+      [ 522770, 179023, "http://example.com/?Andover_Arms" ],
+      [ 522909, 178232, "http://example.com/?Blue Anchor"  ] ];
   my $stations  = [
       [ 523474, 178483, "http://example.com/?Hammersmith" ] ];
-  my $pointsets = [ { points => $pubs,
-                      point_size => 3,
+  my $pointsets = [ { points      => $pubs,
+                      point_size  => 3,
                       point_style => { fill => "blue" }
                     },
-                    { points => $stations,
-                      point_size => 5,
+                    { points      => $stations,
+                      point_size  => 5,
                       point_style => { fill => "red" }
                     } ];
   my $plot = SVG::Plot->new(
-                             pointsets => $pointsets,
-		             scale => 0.025,
-                             max_width => 800,
-                             max_height => 400
+                             pointsets  => $pointsets,
+                             scale      => 0.025,
+                             max_width  => 800,
+                             max_height => 400,
                            );
-   
-you can supply a grid in the format 
+
+To pass options through to L<SVG>, use the C<svg_options> parameter:
+
+  SVG::Plot->new( points      => $points,
+                  svg_options => { -nocredits => 1 }
+                );
+
+You can define the boundaries of the plot:
 
   SVG::Plot->new(
     grid => { min_x => 1,
               min_y => 2,
               max_x => 15,
               max_y => 16 }
-              );
+  );
 
 or
 
   $plot->grid($grid)
 
-this is like a viewbox that shifts the boundaries of the plot.
-
-if it's not specified, the module works out the viewbox from the highest and lowest X and Y co-ordinates in the list(s) of points.
+This is like a viewbox onto the plane of the plot.  If it's not
+specified, the module works out the viewbox from the highest and
+lowest X and Y co-ordinates in the list(s) of points.
 
 Note that the actual margin will be half of the value set
 in C<margin>, since half of it goes to each side.
@@ -152,7 +160,7 @@ sub plot {
     my $grid = $self->grid;
 
     if (not $grid) {
-	$grid = $self->work_out_grid;
+        $grid = $self->work_out_grid;
     }
 
     my $scale = $self->scale || 10;
@@ -162,7 +170,7 @@ sub plot {
     if ( $self->max_width ) {
         my $max_plot_width = $self->max_width - $m; # Account for margin
         croak "max_width must be larger than margin"
-	    if $max_plot_width <= 0;
+            if $max_plot_width <= 0;
         my $x_extent = $grid->{max_x} - $grid->{min_x};
         my $max_width_scale = $max_plot_width / $x_extent;
         $scale = $max_width_scale if $scale > $max_width_scale;
@@ -172,7 +180,7 @@ sub plot {
     if ( $self->max_height ) {
         my $max_plot_height = $self->max_height - $m; # Account for margin
         croak "max_height must be larger than margin"
-	    if $max_plot_height <= 0;
+            if $max_plot_height <= 0;
         my $y_extent = $grid->{max_y} - $grid->{min_y};
         my $max_height_scale = $max_plot_height / $y_extent;
         $scale = $max_height_scale if $scale > $max_height_scale;
@@ -181,14 +189,18 @@ sub plot {
     my $h = int(($grid->{max_y} - $grid->{min_y})*$scale);
     my $w = int(($grid->{max_x} - $grid->{min_x})*$scale);
  
-    my $svg = SVG->new( width => $w+$m, height => $h+$m ); # make a little margin +10
+    my $svg = SVG->new(
+                        width  => $w + $m,
+                        height => $h + $m,
+                        %{ $self->svg_options || {} },
+                      );
 
     if (my $map = $self->image) {
-	my $img = $svg->image(
-			      x=>0, y=>0,
-			      '-href'=>$map, #may also embed SVG, e.g. "image.svg"
-			      id=>'image_1'
-			      );
+        my $img = $svg->image(
+                              x=>0, y=>0,
+                              '-href'=>$map, #may also embed SVG, e.g. "image.svg"
+                              id=>'image_1'
+                              );
     }
 
     # Process each pointset.
@@ -196,12 +208,12 @@ sub plot {
 
     if ( $self->points ) {
         push @pointset_data, { points         => $self->points,
-			       point_size     => $self->point_size,
-			       min_point_size => $self->min_point_size,
-			       max_point_size => $self->max_point_size,
-			       point_style    => $self->point_style,
-			       line           => $self->line,
-			       line_style     => $self->line_style };
+                               point_size     => $self->point_size,
+                               min_point_size => $self->min_point_size,
+                               max_point_size => $self->max_point_size,
+                               point_style    => $self->point_style,
+                               line           => $self->line,
+                               line_style     => $self->line_style };
     }
 
     foreach my $pointset ( @{$self->pointsets || []} ) {
@@ -209,15 +221,15 @@ sub plot {
     }
 
     my %defaults = ( point_size     => $self->point_size,
-		     min_point_size => $self->min_point_size,
-		     max_point_size => $self->max_point_size,
-		     point_style    => $self->point_style );
+                     min_point_size => $self->min_point_size,
+                     max_point_size => $self->max_point_size,
+                     point_style    => $self->point_style );
 
     foreach my $dataset ( @pointset_data ) {
         $self->_plot_pointset( svg         => $svg,
-			       margin      => $m,
-			       grid        => $grid,
-			       scale       => $scale,
+                               margin      => $m,
+                               grid        => $grid,
+                               scale       => $scale,
                                %defaults, # can be overridden by %$dataset
                                %$dataset );
     }
@@ -235,15 +247,15 @@ sub _plot_pointset {
     my $svg = $args{svg} or croak "no SVG object passed";
     my $scale = $args{scale} or croak "no scale passed";
     my $point_style = $args{point_style} || { stroke => 'red',
-					      fill => 'white' };
+                                              fill => 'white' };
 
     my $z = $svg->tag( 'g',
-	               id    => 'group_'.$self->random_id,
-	               style => $point_style
-	             );
+                       id    => 'group_'.$self->random_id,
+                       style => $point_style
+                     );
 
     my $point_size = $args{point_size};
-    if ( $point_size eq "AUTO" ) {
+    if ( $point_size && $point_size eq "AUTO" ) {
         my $min_size = $args{min_point_size} || 1;
         my $max_size = $args{max_point_size} || 10;
         # Make sure we don't send URIs to A::P::MD
@@ -267,45 +279,45 @@ sub _plot_pointset {
     my $plotted;
 
     foreach (@$points) {
-	# adding a margin ... 
-	my $halfm = $args{margin} / 2;
+        # adding a margin ... 
+        my $halfm = $args{margin} / 2;
 
-	my ($x,$y) = ($_->[0],$_->[1]);
-	my $href = $_->[2] || $self->random_id;
-	
-	# svg is upside-down
-	$x = int(($x - $args{grid}->{min_x})*$scale) + $halfm;
-	$y = int(($args{grid}->{max_y} - $y)*$scale) + $halfm;
+        my ($x,$y) = ($_->[0],$_->[1]);
+        my $href = $_->[2] || $self->random_id;
+        
+        # svg is upside-down
+        $x = int(($x - $args{grid}->{min_x})*$scale) + $halfm;
+        $y = int(($args{grid}->{max_y} - $y)*$scale) + $halfm;
 
-	push @$plotted, [$x,$y,$href];
-	my $id = $self->random_id;
-	warn("anchor_$id") if $self->debug;;
+        push @$plotted, [$x,$y,$href];
+        my $id = $self->random_id;
+        warn("anchor_$id") if $self->debug;;
 
-	$z->anchor(id => "anchor_".$id,
-		   -href => $href,
-		   -target => 'new_window_0')->circle(
-						      cx => $x, cy => $y,
-						      r => $point_size,
-						      id    => 'dot_'.$id,
-						  );
+        $z->anchor(id => "anchor_".$id,
+                   -href => $href,
+                   -target => 'new_window_0')->circle(
+                                                      cx => $x, cy => $y,
+                                                      r => $point_size,
+                                                      id    => 'dot_'.$id,
+                                                  );
     }
 
     if (my $line = $args{line}) {
-	my $style = $args{line_style};
-	$style ||= {  'stroke-width' => 2, stroke => 'blue'  };
+        my $style = $args{line_style};
+        $style ||= {  'stroke-width' => 2, stroke => 'blue'  };
 
-	if ($line eq 'follow') {
-	    for my $n (0..($#{$plotted}-1)) {
-		my $p1 = $plotted->[$n];
-		my $p2 = $plotted->[$n+1];
-		my $tag = $svg->line(
-				     id => $self->random_id,
-				     x1 => $p1->[0], y1 => $p1->[1],
-				     x2 => $p2->[0], y2 => $p2->[1],
-				     style => $style
-				     );
-	    }
-	}
+        if ($line eq 'follow') {
+            for my $n (0..($#{$plotted}-1)) {
+                my $p1 = $plotted->[$n];
+                my $p2 = $plotted->[$n+1];
+                my $tag = $svg->line(
+                                     id => $self->random_id,
+                                     x1 => $p1->[0], y1 => $p1->[1],
+                                     x2 => $p2->[0], y2 => $p2->[1],
+                                     style => $style
+                                     );
+            }
+        }
     }
 }
 
@@ -331,17 +343,17 @@ sub work_out_grid {
 
     foreach (@$all_points) {
 
-	$lx = $_->[0] if ($_->[0] <= $lx); 
-	$ly = $_->[1] if ($_->[1] <= $ly);
-	$hx = $_->[0] if ($_->[0] >= $hx);
-	$hy = $_->[1] if ($_->[1] >= $hy);
+        $lx = $_->[0] if ($_->[0] <= $lx); 
+        $ly = $_->[1] if ($_->[1] <= $ly);
+        $hx = $_->[0] if ($_->[0] >= $hx);
+        $hy = $_->[1] if ($_->[1] >= $hy);
     }
     return {
-	min_x => $lx,
-	max_x => $hx,
-	min_y => $ly,
-	max_y => $hy
-	};
+        min_x => $lx,
+        max_x => $hx,
+        min_y => $ly,
+        max_y => $hy
+    };
 }
 
 sub random_id {
